<?php

namespace RelatieApiV6\StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for createKlantKenmerkRequest StructType
 * Meta information extracted from the WSDL
 * - documentation: Maakt een kenmerk aan bij een relatie. Indien het kenmerk bij de relatie reeds bestaat dan kan deze niet nogmaals toegevoegd worden. Dit wordt niet gezien als een fout en wordt het nummer van het reeds geregistreerde kenmerk
 * geretourneerd. <br/> <br/><u>Let op:</u> Deze operatie was voorheen onderdeel van de WebApiV4, maar is verplaatst naar de RelatieApiV6 omdat het relatie-gegevens betreft.
 * @subpackage Structs
 * @date 20240419 package
 */
class CreateKlantKenmerkRequest extends AbstractStructBase
{
    /**
     * The relNo
     * Meta information extracted from the WSDL
     * - documentation: Relatienummer van relatie.
     * - base: xsd:integer
     * - maxOccurs: 1
     * - minOccurs: 1
     * - nillable: false
     * - totalDigits: 15
     * @var int
     */
    public $relNo;
    /**
     * The kenmerkCode
     * Meta information extracted from the WSDL
     * - documentation: Code van het kenmerk. Moet bestaande en actieve kenmerkcode zijn.
     * - base: xsd:string
     * - maxLength: 12
     * - maxOccurs: 1
     * - minLength: 1
     * - minOccurs: 1
     * - nillable: false
     * @var string
     */
    public $kenmerkCode;
    /**
     * The kenmerkGroepCode
     * Meta information extracted from the WSDL
     * - documentation: Code van de kenmerkgroep. Moet bestaande kenmerkgroepcode zijn.
     * - base: xsd:string
     * - maxLength: 12
     * - maxOccurs: 1
     * - minLength: 1
     * - minOccurs: 1
     * - nillable: false
     * @var string
     */
    public $kenmerkGroepCode;
    /**
     * The requestTag
     * Meta information extracted from the WSDL
     * - documentation: Vrij veld voor aanroepende partij. De inhoud van dit veld wordt altijd identiek teruggestuurd.
     * - base: xsd:string
     * - maxLength: 4000
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * @var string
     */
    public $requestTag;
    /**
     * The kenmerkWaarde
     * Meta information extracted from the WSDL
     * - documentation: Optionele waarde van een kenmerk. Van toepassing als bij de kenmerkCode aangegeven is dat er een waarde bij het kenmerk opgegeven kan worden.
     * - base: xsd:string
     * - maxLength: 255
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * @var string
     */
    public $kenmerkWaarde;
    /**
     * The canCreate
     * Meta information extracted from the WSDL
     * - documentation: Indicatie of operatie in de testmodus wordt aangeroepen (er wordt dus geen kenmerk aangemaakt) false (Default) = aanmaken, true = testmodus niet aanmaken.
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * @var bool
     */
    public $canCreate;
    /**
     * Constructor method for createKlantKenmerkRequest
     * @uses CreateKlantKenmerkRequest::setRelNo()
     * @uses CreateKlantKenmerkRequest::setKenmerkCode()
     * @uses CreateKlantKenmerkRequest::setKenmerkGroepCode()
     * @uses CreateKlantKenmerkRequest::setRequestTag()
     * @uses CreateKlantKenmerkRequest::setKenmerkWaarde()
     * @uses CreateKlantKenmerkRequest::setCanCreate()
     * @param int $relNo
     * @param string $kenmerkCode
     * @param string $kenmerkGroepCode
     * @param string $requestTag
     * @param string $kenmerkWaarde
     * @param bool $canCreate
     */
    public function __construct($relNo = null, $kenmerkCode = null, $kenmerkGroepCode = null, $requestTag = null, $kenmerkWaarde = null, $canCreate = null)
    {
        $this
            ->setRelNo($relNo)
            ->setKenmerkCode($kenmerkCode)
            ->setKenmerkGroepCode($kenmerkGroepCode)
            ->setRequestTag($requestTag)
            ->setKenmerkWaarde($kenmerkWaarde)
            ->setCanCreate($canCreate);
    }
    /**
     * Get relNo value
     * @return int
     */
    public function getRelNo()
    {
        return $this->relNo;
    }
    /**
     * Set relNo value
     * @param int $relNo
     * @return \RelatieApiV6\StructType\CreateKlantKenmerkRequest
     */
    public function setRelNo($relNo = null)
    {
        // validation for constraint: int
        if (!is_null($relNo) && !(is_int($relNo) || ctype_digit($relNo))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($relNo, true), gettype($relNo)), __LINE__);
        }
        // validation for constraint: totalDigits(15)
        if (!is_null($relNo) && mb_strlen(preg_replace('/(\D)/', '', $relNo)) > 15) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, the value must use at most 15 digits, "%d" given', var_export($relNo, true), mb_strlen(preg_replace('/(\D)/', '', $relNo))), __LINE__);
        }
        $this->relNo = $relNo;
        return $this;
    }
    /**
     * Get kenmerkCode value
     * @return string
     */
    public function getKenmerkCode()
    {
        return $this->kenmerkCode;
    }
    /**
     * Set kenmerkCode value
     * @param string $kenmerkCode
     * @return \RelatieApiV6\StructType\CreateKlantKenmerkRequest
     */
    public function setKenmerkCode($kenmerkCode = null)
    {
        // validation for constraint: string
        if (!is_null($kenmerkCode) && !is_string($kenmerkCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($kenmerkCode, true), gettype($kenmerkCode)), __LINE__);
        }
        // validation for constraint: maxLength(12)
        if (!is_null($kenmerkCode) && mb_strlen($kenmerkCode) > 12) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 12', mb_strlen($kenmerkCode)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($kenmerkCode) && mb_strlen($kenmerkCode) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($kenmerkCode)), __LINE__);
        }
        $this->kenmerkCode = $kenmerkCode;
        return $this;
    }
    /**
     * Get kenmerkGroepCode value
     * @return string
     */
    public function getKenmerkGroepCode()
    {
        return $this->kenmerkGroepCode;
    }
    /**
     * Set kenmerkGroepCode value
     * @param string $kenmerkGroepCode
     * @return \RelatieApiV6\StructType\CreateKlantKenmerkRequest
     */
    public function setKenmerkGroepCode($kenmerkGroepCode = null)
    {
        // validation for constraint: string
        if (!is_null($kenmerkGroepCode) && !is_string($kenmerkGroepCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($kenmerkGroepCode, true), gettype($kenmerkGroepCode)), __LINE__);
        }
        // validation for constraint: maxLength(12)
        if (!is_null($kenmerkGroepCode) && mb_strlen($kenmerkGroepCode) > 12) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 12', mb_strlen($kenmerkGroepCode)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($kenmerkGroepCode) && mb_strlen($kenmerkGroepCode) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($kenmerkGroepCode)), __LINE__);
        }
        $this->kenmerkGroepCode = $kenmerkGroepCode;
        return $this;
    }
    /**
     * Get requestTag value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return string|null
     */
    public function getRequestTag()
    {
        return isset($this->requestTag) ? $this->requestTag : null;
    }
    /**
     * Set requestTag value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param string $requestTag
     * @return \RelatieApiV6\StructType\CreateKlantKenmerkRequest
     */
    public function setRequestTag($requestTag = null)
    {
        // validation for constraint: string
        if (!is_null($requestTag) && !is_string($requestTag)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($requestTag, true), gettype($requestTag)), __LINE__);
        }
        // validation for constraint: maxLength(4000)
        if (!is_null($requestTag) && mb_strlen($requestTag) > 4000) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 4000', mb_strlen($requestTag)), __LINE__);
        }
        if (is_null($requestTag) || (is_array($requestTag) && empty($requestTag))) {
            unset($this->requestTag);
        } else {
            $this->requestTag = $requestTag;
        }
        return $this;
    }
    /**
     * Get kenmerkWaarde value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return string|null
     */
    public function getKenmerkWaarde()
    {
        return isset($this->kenmerkWaarde) ? $this->kenmerkWaarde : null;
    }
    /**
     * Set kenmerkWaarde value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param string $kenmerkWaarde
     * @return \RelatieApiV6\StructType\CreateKlantKenmerkRequest
     */
    public function setKenmerkWaarde($kenmerkWaarde = null)
    {
        // validation for constraint: string
        if (!is_null($kenmerkWaarde) && !is_string($kenmerkWaarde)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($kenmerkWaarde, true), gettype($kenmerkWaarde)), __LINE__);
        }
        // validation for constraint: maxLength(255)
        if (!is_null($kenmerkWaarde) && mb_strlen($kenmerkWaarde) > 255) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 255', mb_strlen($kenmerkWaarde)), __LINE__);
        }
        if (is_null($kenmerkWaarde) || (is_array($kenmerkWaarde) && empty($kenmerkWaarde))) {
            unset($this->kenmerkWaarde);
        } else {
            $this->kenmerkWaarde = $kenmerkWaarde;
        }
        return $this;
    }
    /**
     * Get canCreate value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return bool|null
     */
    public function getCanCreate()
    {
        return isset($this->canCreate) ? $this->canCreate : null;
    }
    /**
     * Set canCreate value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param bool $canCreate
     * @return \RelatieApiV6\StructType\CreateKlantKenmerkRequest
     */
    public function setCanCreate($canCreate = null)
    {
        // validation for constraint: boolean
        if (!is_null($canCreate) && !is_bool($canCreate)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a bool, %s given', var_export($canCreate, true), gettype($canCreate)), __LINE__);
        }
        if (is_null($canCreate) || (is_array($canCreate) && empty($canCreate))) {
            unset($this->canCreate);
        } else {
            $this->canCreate = $canCreate;
        }
        return $this;
    }
}
